@@ -61,7 +61,7 @@ define!({
         pub span: Span,
         pub name: DeclarationName,
         pub value: Vec<Value>,
-        pub important: Option<Span>,
+        pub important: Option<ImportantFlag>,
     }
 
     pub enum DeclarationName {
@@ -69,6 +69,11 @@ define!({
         DashedIdent(DashedIdent),
     }
 
+    pub struct ImportantFlag {
+        pub span: Span,
+        pub value: Ident,
+    }
+
     pub struct QualifiedRule {
         pub span: Span,
         pub prelude: SelectorList,
